==> jam.py-1.0.1.tar.gz: jam.py-1.0.1/jam/project/js/bootstrap-modal.js <==
/* ===========================================================
 * bootstrap-modal.js v2.1
 * ===========================================================
 * Copyright 2012 Jordan Schroter
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 * ========================================================== */


!function ($) {

    "use strict"; // jshint ;_;

    /* MODAL CLASS DEFINITION
    * ====================== */

    var Modal = function (element, options) {
        this.init(element, options);
    };

    Modal.prototype = {

        constructor: Modal,

        init: function (element, options) {
            this.options = options;

            this.$element = $(element)
                .delegate('[data-dismiss="modal"]', 'click.dismiss.modal', $.proxy(this.hide, this));

            this.options.remote && this.$element.find('.modal-body').load(this.options.remote);

            var manager = typeof this.options.manager === 'function' ?
                this.options.manager.call(this) : this.options.manager;

            manager = manager.appendModal ?
                manager : $(manager).modalmanager().data('modalmanager');

            manager.appendModal(this);

            this.manager = manager;
        },

        toggle: function () {
            return this[!this.isShown ? 'show' : 'hide']();
        },

        show: function () {
            var e = $.Event('show');

            if (this.isShown) return;

            this.$element.trigger(e);

            if (e.isDefaultPrevented()) return;

            this.escape();

            this.options.loading && this.loading();

            this.tab();
        },

        hide: function (e) {
            e && e.preventDefault();

            e = $.Event('hide');

            this.$element.trigger(e);

            if (!this.isShown || e.isDefaultPrevented()) return (this.isShown = true);

            this.isShown = false;

            this.escape();

            this.tab();

            this.isLoading && this.loading();

            $(document).off('focusin.modal');

            this.$element
                .removeClass('in')
                .removeClass('animated')
                .removeClass(this.options.attentionAnimation)
                .removeClass('modal-overflow')
                .attr('aria-hidden', true);

            $.support.transition && this.$element.hasClass('fade') ?
                this.hideWithTransition() :
                this.hideModal();
        },

        layout: function () {
            var prop = this.options.height ? 'height' : 'max-height',
                value = this.options.height || this.options.maxHeight;

            if (this.options.width){
                this.$element.css('width', this.options.width);

                var that = this;
                this.$element.css('margin-left', function () {
                    if (/%/ig.test(that.options.width)){
                        return -(parseInt(that.options.width) / 2) + '%';
                    } else {
                        return -($(this).width() / 2) + 'px';
                    }
                });
            } else {
                this.$element.css('width', '');
                this.$element.css('margin-left', '');
            }

            //~ this.$element.find('.modal-body')
                //~ .css('overflow', '')
                //~ .css(prop, '');
//~
            //~ if (value){
                //~ this.$element.find('.modal-body')
                    //~ .css('overflow', 'auto')
                    //~ .css(prop, value);
            //~ }

            this.$element
                .css('overflow', '')
                .css(prop, '');

            if (value){
                this.$element
                    .css('overflow', 'auto')
                    .css(prop, value);
            }

            var modalOverflow = $(window).height() - 10 < this.$element.height();
            if (modalOverflow || this.options.modalOverflow) {
                this.$element
                    .css('margin-top', 0)
                    .addClass('modal-overflow');
            } else {
                this.$element
                    .css('margin-top', 0 - this.$element.height() / 2)
//                    .addClass('modal-overflow');
                    .removeClass('modal-overflow');
            }
        },

        validTabElement: function(element) {
            var tagName = element.tagName,
                tabIndex = element.tabIndex,
                $element = $(element);
            if (tabIndex < 0 || $element.is(':hidden')) {
                return false;
            }
            //~ if (!(tabIndex >= 0)) {
                //~ if ((tagName === 'A')
                    //~ || (tagName === 'LINK')
                    //~ || (tagName === 'BUTTON')
                    //~ || (tagName === 'INPUT')
                    //~ || (tagName === 'SELECT')
                    //~ || (tagName === 'TEXTAREA')
                    //~ || (tagName === 'MENUITEM')) {
                    //~ $element.attr('tabindex', 0);
                //~ }
            //~ }
            if ((tagName === 'INPUT') || (tagName === 'TEXTAREA')) {
                return $element.is(':enabled:not([readonly])');
            }
            else if ((tagName === 'BUTTON')
                || (tagName === 'FIELDSET')
                || (tagName === 'OPTGROUP')
                || (tagName === 'OPTION')
                || (tagName === 'SELECT')) {
                return $element.is(':enabled');
            } else if (tabIndex >= 0) {
                return true;
            }
        },

        validInputElement: function(element) {
            var $element = $($element);
            if ($element.is('input') || $element.is('textarea')) {
                if (!$element.is(':hidden') && ($element.attr('tabindex') >= 0)) {
                    console.log($element.get(0).tagName);
                    return $element.is(':enabled:not([readonly])');
                }
            }
        },

        getTabChildren: function(el, validFunc, result) {
            var i,
                len,
                nodes;
            if (el.nodeType === 1) {
                if (validFunc(el)) {
                    result.push(el);
                }
                nodes = el.childNodes;
                if (nodes && !(el.tagName === 'THEAD') && !(el.tagName === 'TABLE' && el.className.indexOf('inner-table') >= 0)) {
                    len = nodes.length;
                    for (i = 0; i < len; i++) {
                        this.getTabChildren(nodes[i], validFunc, result);
                    }
                }
            }
        },

        tabList: function(validFunc) {
            var self = this,
                result = [];
            if (!validFunc) {
                validFunc = this.validTabElement;
            }
            this.getTabChildren(this.$element.get(0), validFunc, result);

            result.sort(function(a, b) {
                var aIndex = a.tabIndex,
                    bIndex = b.tabIndex;
                if (aIndex === bIndex) {
                    return 0
                }
                else if (aIndex === 0) {
                    return 1;
                }
                else if (bIndex === 0) {
                    return -1;
                }
                else {
                    return (aIndex > bIndex) ? 1: -1;
                }
            });
            return result;
        },

        tab: function () {
            var key,
                that = this;
            if (this.isShown && this.options.consumeTab) {
                this.$element.on('keydown.tabindex.modal', function (e) {
                    var tabs,
                        curIndex;
                    if (e.target.tabIndex >= 0) {
                        key = e.charCode ? e.charCode : e.keyCode ? e.keyCode : 0;
                        if (key === 9 || (e.target.tagName !== 'TABLE') && (key === 38 || key === 40)){
                            tabs = that.tabList(that.validTabElement);
                            curIndex = tabs.indexOf(e.target);
                            if (curIndex !== -1) {
                                if ((!e.shiftKey && key === 9) || key === 40){
                                    curIndex++;
                                }
                                else {
                                    curIndex--;
                                }
                                if (curIndex < 0) {
                                    curIndex = tabs.length -1;
                                }
                                if (curIndex > tabs.length -1) {
                                    curIndex = 0;
                                }
                                $(tabs[curIndex]).focus();
                                e.preventDefault();
                                e.stopPropagation();
                            }
                        }
                    }
                })
            } else if (!this.isShown) {
                this.$element.off('keydown.tabindex.modal');
            }
        },

        escape: function () {
            var that = this;
            if (this.isShown && this.options.keyboard) {
                if (!this.$element.attr('tabindex')) this.$element.attr('tabindex', -1);

                this.$element.on('keyup.dismiss.modal', function (e) {
                    e.which == 27 && that.hide();
                });
            } else if (!this.isShown) {
                this.$element.off('keyup.dismiss.modal')
            }
        },

        hideWithTransition: function () {
            var that = this
                , timeout = setTimeout(function () {
                    that.$element.off($.support.transition.end);
                    that.hideModal();
                }, 500);

            this.$element.one($.support.transition.end, function () {
                clearTimeout(timeout);
                that.hideModal();
            });
        },

        hideModal: function () {
            var prop = this.options.height ? 'height' : 'max-height';
            var value = this.options.height || this.options.maxHeight;

            if (value){
                this.$element.find('.modal-body')
                    .css('overflow', '')
                    .css(prop, '');
            }

            this.$element
                .hide()
                .trigger('hidden');
        },

        removeLoading: function () {
            this.$loading.remove();
            this.$loading = null;
            this.isLoading = false;
        },

        loading: function (callback) {
            callback = callback || function () {};

            var animate = this.$element.hasClass('fade') ? 'fade' : '';

            if (!this.isLoading) {
                var doAnimate = $.support.transition && animate;

                this.$loading = $('<div class="loading-mask ' + animate + '">')
                    .append(this.options.spinner)
                    .appendTo(this.$element);

                if (doAnimate) this.$loading[0].offsetWidth; // force reflow

                this.$loading.addClass('in');

                this.isLoading = true;

                doAnimate ?
                    this.$loading.one($.support.transition.end, callback) :
                    callback();

            } else if (this.isLoading && this.$loading) {
                this.$loading.removeClass('in');

                var that = this;
                $.support.transition && this.$element.hasClass('fade')?
                    this.$loading.one($.support.transition.end, function () { that.removeLoading() }) :
                    that.removeLoading();

            } else if (callback) {
                callback(this.isLoading);
            }
        },

        focus: function () {
            var $focusElem = this.$element.find(this.options.focusOn);

            $focusElem = $focusElem.length ? $focusElem : this.$element;

            $focusElem.focus();
        },

        attention: function (){
            // NOTE: transitionEnd with keyframes causes odd behaviour

            if (this.options.attentionAnimation){
                this.$element
                    .removeClass('animated')
                    .removeClass(this.options.attentionAnimation);

                var that = this;

                setTimeout(function () {
                    that.$element
                        .addClass('animated')
                        .addClass(that.options.attentionAnimation);
                }, 0);
            }


            this.focus();
        },


        destroy: function () {
            var e = $.Event('destroy');
            this.$element.trigger(e);
            if (e.isDefaultPrevented()) return;

            this.teardown();
        },

        teardown: function () {
            if (!this.$parent.length){
                this.$element.remove();
                this.$element = null;
                return;
            }

            if (this.$parent !== this.$element.parent()){
                this.$element.appendTo(this.$parent);
            }

            this.$element.off('.modal');
            this.$element.removeData('modal');
            this.$element
                .removeClass('in')
                .attr('aria-hidden', true);
        }
    };


    /* MODAL PLUGIN DEFINITION
    * ======================= */

    $.fn.modal = function (option, args) {
        return this.each(function () {
            var $this = $(this),
                data = $this.data('modal'),
                options = $.extend({}, $.fn.modal.defaults, $this.data(), typeof option == 'object' && option);

            if (!data) $this.data('modal', (data = new Modal(this, options)));
            if (typeof option == 'string') data[option].apply(data, [].concat(args));
            else if (options.show) data.show()
        })
    };

    $.fn.modal.defaults = {
        keyboard: true,
        backdrop: true,
        loading: false,
        show: true,
        width: null,
        height: null,
        maxHeight: null,
        modalOverflow: false,
        consumeTab: true,
        focusOn: null,
        replace: false,
        resize: true,
        attentionAnimation: 'shake',
        manager: 'body',
        spinner: '<div class="loading-spinner" style="width: 200px; margin-left: -100px;"><div class="progress progress-striped active"><div class="bar" style="width: 100%;"></div></div></div>'
    };

    $.fn.modal.Constructor = Modal;


    /* MODAL DATA-API
    * ============== */

    $(function () {
        $(document).off('click.modal').on('click.modal.data-api', '[data-toggle="modal"]', function ( e ) {
            var $this = $(this),
                href = $this.attr('href'),
                $target = $($this.attr('data-target') || (href && href.replace(/.*(?=#[^\s]+$)/, ''))), //strip for ie7
                option = $target.data('modal') ? 'toggle' : $.extend({ remote: !/#/.test(href) && href }, $target.data(), $this.data());

            e.preventDefault();
            $target
                .modal(option)
                .one('hide', function () {
                    $this.focus();
                })
        });
    });

    /* CAN FOCUS
    * ============== */

    $.fn.modalCanFocus = function () {
        var result = true,
            $modal = this.closest('.modal'),
            modal = $modal.data('modal');
        if (modal && modal.manager) {
            result = modal.zPos === modal.manager.getMaxzPos();
        }
        return result;
    }

}(window.jQuery);

==> jam.py-1.0.7.tar.gz: jam.py-1.0.7/jam/project/js/bootstrap-modal.js <==
/* ===========================================================
 * bootstrap-modal.js v2.1
 * ===========================================================
 * Copyright 2012 Jordan Schroter
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 * ========================================================== */


!function ($) {

    "use strict"; // jshint ;_;

    /* MODAL CLASS DEFINITION
    * ====================== */

    var Modal = function (element, options) {
        this.init(element, options);
    };

    Modal.prototype = {

        constructor: Modal,

        init: function (element, options) {
            this.options = options;

            this.$element = $(element)
                .delegate('[data-dismiss="modal"]', 'click.dismiss.modal', $.proxy(this.hide, this));

            this.options.remote && this.$element.find('.modal-body').load(this.options.remote);

            var manager = typeof this.options.manager === 'function' ?
                this.options.manager.call(this) : this.options.manager;

            manager = manager.appendModal ?
                manager : $(manager).modalmanager().data('modalmanager');

            manager.appendModal(this);

            this.manager = manager;
        },

        toggle: function () {
            return this[!this.isShown ? 'show' : 'hide']();
        },

        show: function () {
            var e = $.Event('show');

            if (this.isShown) return;

            this.$element.trigger(e);

            if (e.isDefaultPrevented()) return;

            this.escape();

            this.options.loading && this.loading();

            this.tab();
        },

        hide: function (e) {
            e && e.preventDefault();

            e = $.Event('hide');

            this.$element.trigger(e);

            if (!this.isShown || e.isDefaultPrevented()) return (this.isShown = true);

            this.isShown = false;

            this.escape();

            this.tab();

            this.isLoading && this.loading();

            $(document).off('focusin.modal');

            this.$element
                .removeClass('in')
                .removeClass('animated')
                .removeClass(this.options.attentionAnimation)
                .removeClass('modal-overflow')
                .attr('aria-hidden', true);

            $.support.transition && this.$element.hasClass('fade') ?
                this.hideWithTransition() :
                this.hideModal();
        },

        layout: function () {
            var prop = this.options.height ? 'height' : 'max-height',
                value = this.options.height || this.options.maxHeight;

            if (this.options.width){
                this.$element.css('width', this.options.width);

                var that = this;
                this.$element.css('margin-left', function () {
                    if (/%/ig.test(that.options.width)){
                        return -(parseInt(that.options.width) / 2) + '%';
                    } else {
                        return -($(this).width() / 2) + 'px';
                    }
                });
            } else {
                this.$element.css('width', '');
                this.$element.css('margin-left', '');
            }

            //~ this.$element.find('.modal-body')
                //~ .css('overflow', '')
                //~ .css(prop, '');
//~
            //~ if (value){
                //~ this.$element.find('.modal-body')
                    //~ .css('overflow', 'auto')
                    //~ .css(prop, value);
            //~ }

            this.$element
                .css('overflow', '')
                .css(prop, '');

            if (value){
                this.$element
                    .css('overflow', 'auto')
                    .css(prop, value);
            }

            var modalOverflow = $(window).height() - 10 < this.$element.height();
            if (modalOverflow || this.options.modalOverflow) {
                this.$element
                    .css('margin-top', 0)
                    .addClass('modal-overflow');
            } else {
                this.$element
                    .css('margin-top', 0 - this.$element.height() / 2)
//                    .addClass('modal-overflow');
                    .removeClass('modal-overflow');
            }
        },

        validTabElement: function(element) {
            var tagName = element.tagName,
                tabIndex = element.tabIndex,
                $element = $(element);
            if (tabIndex < 0 || $element.is(':hidden')) {
                return false;
            }
            //~ if (!(tabIndex >= 0)) {
                //~ if ((tagName === 'A')
                    //~ || (tagName === 'LINK')
                    //~ || (tagName === 'BUTTON')
                    //~ || (tagName === 'INPUT')
                    //~ || (tagName === 'SELECT')
                    //~ || (tagName === 'TEXTAREA')
                    //~ || (tagName === 'MENUITEM')) {
                    //~ $element.attr('tabindex', 0);
                //~ }
            //~ }
            if ((tagName === 'INPUT') || (tagName === 'TEXTAREA')) {
                return $element.is(':enabled:not([readonly])');
            }
            else if ((tagName === 'BUTTON')
                || (tagName === 'FIELDSET')
                || (tagName === 'OPTGROUP')
                || (tagName === 'OPTION')
                || (tagName === 'SELECT')) {
                return $element.is(':enabled');
            } else if (tabIndex >= 0) {
                return true;
            }
        },

        validInputElement: function(element) {
            var $element = $($element);
            if ($element.is('input') || $element.is('textarea')) {
                if (!$element.is(':hidden') && ($element.attr('tabindex') >= 0)) {
                    console.log($element.get(0).tagName);
                    return $element.is(':enabled:not([readonly])');
                }
            }
        },

        getTabChildren: function(el, validFunc, result) {
            var i,
                len,
                nodes;
            if (el.nodeType === 1) {
                if (validFunc(el)) {
                    result.push(el);
                }
                nodes = el.childNodes;
                if (nodes && !(el.tagName === 'THEAD') && !(el.tagName === 'TABLE' && el.className.indexOf('inner-table') >= 0)) {
                    len = nodes.length;
                    for (i = 0; i < len; i++) {
                        this.getTabChildren(nodes[i], validFunc, result);
                    }
                }
            }
        },

        tabList: function(validFunc) {
            var self = this,
                result = [];
            if (!validFunc) {
                validFunc = this.validTabElement;
            }
            this.getTabChildren(this.$element.get(0), validFunc, result);

            result.sort(function(a, b) {
                var aIndex = a.tabIndex,
                    bIndex = b.tabIndex;
                if (aIndex === bIndex) {
                    return 0
                }
                else if (aIndex === 0) {
                    return 1;
                }
                else if (bIndex === 0) {
                    return -1;
                }
                else {
                    return (aIndex > bIndex) ? 1: -1;
                }
            });
            return result;
        },

        tab: function () {
            var key,
                that = this;
            if (this.isShown && this.options.consumeTab) {
                this.$element.on('keydown.tabindex.modal', function (e) {
                    var tabs,
                        curIndex;
                    if (e.target.tabIndex >= 0) {
                        key = e.charCode ? e.charCode : e.keyCode ? e.keyCode : 0;
                        if (key === 9 || (e.target.tagName !== 'TABLE') && (key === 38 || key === 40)){
                            tabs = that.tabList(that.validTabElement);
                            curIndex = tabs.indexOf(e.target);
                            if (curIndex !== -1) {
                                if ((!e.shiftKey && key === 9) || key === 40){
                                    curIndex++;
                                }
                                else {
                                    curIndex--;
                                }
                                if (curIndex < 0) {
                                    curIndex = tabs.length -1;
                                }
                                if (curIndex > tabs.length -1) {
                                    curIndex = 0;
                                }
                                $(tabs[curIndex]).focus();
                                e.preventDefault();
                                e.stopPropagation();
                            }
                        }
                    }
                })
            } else if (!this.isShown) {
                this.$element.off('keydown.tabindex.modal');
            }
        },

        escape: function () {
            var that = this;
            if (this.isShown && this.options.keyboard) {
                if (!this.$element.attr('tabindex')) this.$element.attr('tabindex', -1);

                this.$element.on('keyup.dismiss.modal', function (e) {
                    e.which == 27 && that.hide();
                });
            } else if (!this.isShown) {
                this.$element.off('keyup.dismiss.modal')
            }
        },

        hideWithTransition: function () {
            var that = this
                , timeout = setTimeout(function () {
                    that.$element.off($.support.transition.end);
                    that.hideModal();
                }, 500);

            this.$element.one($.support.transition.end, function () {
                clearTimeout(timeout);
                that.hideModal();
            });
        },

        hideModal: function () {
            var prop = this.options.height ? 'height' : 'max-height';
            var value = this.options.height || this.options.maxHeight;

            if (value){
                this.$element.find('.modal-body')
                    .css('overflow', '')
                    .css(prop, '');
            }

            this.$element
                .hide()
                .trigger('hidden');
        },

        removeLoading: function () {
            this.$loading.remove();
            this.$loading = null;
            this.isLoading = false;
        },

        loading: function (callback) {
            callback = callback || function () {};

            var animate = this.$element.hasClass('fade') ? 'fade' : '';

            if (!this.isLoading) {
                var doAnimate = $.support.transition && animate;

                this.$loading = $('<div class="loading-mask ' + animate + '">')
                    .append(this.options.spinner)
                    .appendTo(this.$element);

                if (doAnimate) this.$loading[0].offsetWidth; // force reflow

                this.$loading.addClass('in');

                this.isLoading = true;

                doAnimate ?
                    this.$loading.one($.support.transition.end, callback) :
                    callback();

            } else if (this.isLoading && this.$loading) {
                this.$loading.removeClass('in');

                var that = this;
                $.support.transition && this.$element.hasClass('fade')?
                    this.$loading.one($.support.transition.end, function () { that.removeLoading() }) :
                    that.removeLoading();

            } else if (callback) {
                callback(this.isLoading);
            }
        },

        focus: function () {
            var $focusElem = this.$element.find(this.options.focusOn);

            $focusElem = $focusElem.length ? $focusElem : this.$element;

            $focusElem.focus();
        },

        attention: function (){
            // NOTE: transitionEnd with keyframes causes odd behaviour

            if (this.options.attentionAnimation){
                this.$element
                    .removeClass('animated')
                    .removeClass(this.options.attentionAnimation);

                var that = this;

                setTimeout(function () {
                    that.$element
                        .addClass('animated')
                        .addClass(that.options.attentionAnimation);
                }, 0);
            }


            this.focus();
        },


        destroy: function () {
            var e = $.Event('destroy');
            this.$element.trigger(e);
            if (e.isDefaultPrevented()) return;

            this.teardown();
        },

        teardown: function () {
            if (!this.$parent.length){
                this.$element.remove();
                this.$element = null;
                return;
            }

            if (this.$parent !== this.$element.parent()){
                this.$element.appendTo(this.$parent);
            }

            this.$element.off('.modal');
            this.$element.removeData('modal');
            this.$element
                .removeClass('in')
                .attr('aria-hidden', true);
        }
    };


    /* MODAL PLUGIN DEFINITION
    * ======================= */

    $.fn.modal = function (option, args) {
        return this.each(function () {
            var $this = $(this),
                data = $this.data('modal'),
                options = $.extend({}, $.fn.modal.defaults, $this.data(), typeof option == 'object' && option);

            if (!data) $this.data('modal', (data = new Modal(this, options)));
            if (typeof option == 'string') data[option].apply(data, [].concat(args));
            else if (options.show) data.show()
        })
    };

    $.fn.modal.defaults = {
        keyboard: true,
        backdrop: true,
        loading: false,
        show: true,
        width: null,
        height: null,
        maxHeight: null,
        modalOverflow: false,
        consumeTab: true,
        focusOn: null,
        replace: false,
        resize: true,
        attentionAnimation: 'shake',
        manager: 'body',
        spinner: '<div class="loading-spinner" style="width: 200px; margin-left: -100px;"><div class="progress progress-striped active"><div class="bar" style="width: 100%;"></div></div></div>'
    };

    $.fn.modal.Constructor = Modal;


    /* MODAL DATA-API
    * ============== */

    $(function () {
        $(document).off('click.modal').on('click.modal.data-api', '[data-toggle="modal"]', function ( e ) {
            var $this = $(this),
                href = $this.attr('href'),
                $target = $($this.attr('data-target') || (href && href.replace(/.*(?=#[^\s]+$)/, ''))), //strip for ie7
                option = $target.data('modal') ? 'toggle' : $.extend({ remote: !/#/.test(href) && href }, $target.data(), $this.data());

            e.preventDefault();
            $target
                .modal(option)
                .one('hide', function () {
                    $this.focus();
                })
        });
    });

    /* CAN FOCUS
    * ============== */

    $.fn.modalForm = function() {
        return this.closest('.modal');
    }

    $.fn.modalCanFocus = function () {
        var result = true,
            $modal = this.closest('.modal'),
            modal = $modal.data('modal'),
            manager;
        if (modal) {
            if (modal.manager) {
                result = modal.zPos === modal.manager.getMaxzPos();
            }
        }
        else {
            manager = $.fn.modal.defaults.manager;
            manager = typeof manager === 'function' ? manager.call(this) : manager;
            manager = manager.appendModal ?
                manager : $(manager).modalmanager().data('modalmanager');
            if (manager) {
                result = manager.getMaxzPos() === 0;
            }
        }
        return result;
    }

}(window.jQuery);
